==> 1.0.2.tar.gz: doc/UsageApi.md <==
# forestvpn_api.api.UsageApi

## Load the API package
```dart
import 'package:forestvpn_api/api.dart';
```

All URIs are relative to *https://api.forestvpn.com/v1*

Method | HTTP request | Description
------------- | ------------- | -------------
[**getTraffic**](UsageApi.md#getTraffic) | **GET** /usage/traffic/ | Get traffic usage for current month
[**trafficUpdate**](UsageApi.md#trafficUpdate) | **POST** /usage/traffic/ | Usage traffic update


# **getTraffic**
> UsageTraffic getTraffic()

Get traffic usage for current month

### Example 
```dart
import 'package:forestvpn_api/api.dart';
// TODO Configure API key authorization: Bearer
//forestvpn_api.api.Configuration.apiKey{'Authorization'} = 'YOUR_API_KEY';
// uncomment below to setup prefix (e.g. Bearer) for API key, if needed
//forestvpn_api.api.Configuration.apiKeyPrefix{'Authorization'} = "Bearer";

var api_instance = new UsageApi();

try { 
    var result = api_instance.getTraffic();
    print(result);
} catch (e) {
    print("Exception when calling UsageApi->getTraffic: $e\n");
}
```

### Parameters
This endpoint does not need any parameter.

### Return type

[**UsageTraffic**](UsageTraffic.md)

### Authorization

[Bearer](../README.md#Bearer)

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **trafficUpdate**
> trafficUpdate(request)

Usage traffic update

### Example 
```dart
import 'package:forestvpn_api/api.dart';
// TODO Configure API key authorization: Bearer
//forestvpn_api.api.Configuration.apiKey{'Authorization'} = 'YOUR_API_KEY';
// uncomment below to setup prefix (e.g. Bearer) for API key, if needed
//forestvpn_api.api.Configuration.apiKeyPrefix{'Authorization'} = "Bearer";

var api_instance = new UsageApi();
var request = [new List&lt;UsageTrafficUpdateRequest&gt;()]; // List<UsageTrafficUpdateRequest> | 

try { 
    api_instance.trafficUpdate(request);
} catch (e) {
    print("Exception when calling UsageApi->trafficUpdate: $e\n");
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **request** | [**List&lt;UsageTrafficUpdateRequest&gt;**](UsageTrafficUpdateRequest.md)|  | [optional] 

### Return type

void (empty response body)

### Authorization

[Bearer](../README.md#Bearer)

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

==> 1.0.3.tar.gz: doc/UsageApi.md <==
# forestvpn_api.api.UsageApi

## Load the API package
```dart
import 'package:forestvpn_api/api.dart';
```

All URIs are relative to *https://api.forestvpn.com/v1*

Method | HTTP request | Description
------------- | ------------- | -------------
[**getTraffic**](UsageApi.md#getTraffic) | **GET** /usage/traffic/ | Get traffic usage for current month
[**trafficUpdate**](UsageApi.md#trafficUpdate) | **POST** /usage/traffic/ | Usage traffic update


# **getTraffic**
> UsageTraffic getTraffic()

Get traffic usage for current month

### Example 
```dart
import 'package:forestvpn_api/api.dart';
// TODO Configure API key authorization: Bearer
//defaultApiClient.getAuthentication<ApiKeyAuth>('Bearer').apiKey = 'YOUR_API_KEY';
// uncomment below to setup prefix (e.g. Bearer) for API key, if needed
//defaultApiClient.getAuthentication<ApiKeyAuth>('Bearer').apiKeyPrefix = 'Bearer';

var api_instance = UsageApi();

try { 
    var result = api_instance.getTraffic();
    print(result);
} catch (e) {
    print("Exception when calling UsageApi->getTraffic: $e\n");
}
```

### Parameters
This endpoint does not need any parameter.

### Return type

[**UsageTraffic**](UsageTraffic.md)

### Authorization

[Bearer](../README.md#Bearer)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **trafficUpdate**
> trafficUpdate(request)

Usage traffic update

### Example 
```dart
import 'package:forestvpn_api/api.dart';
// TODO Configure API key authorization: Bearer
//defaultApiClient.getAuthentication<ApiKeyAuth>('Bearer').apiKey = 'YOUR_API_KEY';
// uncomment below to setup prefix (e.g. Bearer) for API key, if needed
//defaultApiClient.getAuthentication<ApiKeyAuth>('Bearer').apiKeyPrefix = 'Bearer';

var api_instance = UsageApi();
var request = [List&lt;UsageTrafficUpdateRequest&gt;()]; // List<UsageTrafficUpdateRequest> | 

try { 
    api_instance.trafficUpdate(request);
} catch (e) {
    print("Exception when calling UsageApi->trafficUpdate: $e\n");
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **request** | [**List&lt;UsageTrafficUpdateRequest&gt;**](UsageTrafficUpdateRequest.md)|  | [optional] 

### Return type

void (empty response body)

### Authorization

[Bearer](../README.md#Bearer)

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)
